# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['wglestaapi']

package_data = \
{'': ['*']}

setup_kwargs = {
    'name': 'wglestaapi',
    'version': '0.3.0',
    'description': 'Unofficial Python library that implements the Wargaming.net API and Lesta Games API functionality',
    'long_description': '# WgLestaAPI\n\nUnofficial Python library that facilitates working with **<a href="https://developers.wargaming.net"><img src="docs/icons/wg.ico" width=15px> API Wargaming.net</a>** and **<a href="https://developers.lesta.ru"><img src="docs/icons/lesta.ico" width=15px> API Lesta Games</a>** functionality via **Python**.\n\n[![Downloads](https://static.pepy.tech/personalized-badge/wglestaapi?period=total&units=international_system&left_color=grey&right_color=blue&left_text=downloads)](https://pepy.tech/project/wglestaapi)\n[![Downloads](https://static.pepy.tech/personalized-badge/wglestaapi?period=month&units=international_system&left_color=grey&right_color=blue&left_text=downloads/month)](https://pepy.tech/project/wglestaapi)\n[![Downloads](https://static.pepy.tech/personalized-badge/wglestaapi?period=week&units=international_system&left_color=grey&right_color=blue&left_text=downloads/week)](https://pepy.tech/project/wglestaapi)\n[![Supported Versions](https://img.shields.io/pypi/pyversions/wglestaapi)](https://pypi.org/project/wglestaapi)\n[![Version](https://img.shields.io/pypi/v/wglestaapi?color=success)](https://pypi.org/project/wglestaapi)\n[![](https://img.shields.io/pypi/format/wglestaapi)](https://pypi.org/project/wglestaapi)\n[![](https://img.shields.io/pypi/wheel/wglestaapi)](https://pypi.org/project/wglestaapi)\n[![GitHub Repo stars](https://img.shields.io/github/stars/tankalxat34/wglestaapi?style=social)](https://github.com/tankalxat34/wglestaapi)\n\nBy downloading this library you fully agree with all official documents **Lesta Games** and **Wargaming.net** about **Lesta Games** and **Wargaming.net** products. *The author of the library ([Alexander Podstrechny](https://github.com/tankalxat34)) is not responsible for your actions performed with the help of this program code.*\n\n## Installing the library\n\nRun the command below at the command line\n\n```\npip install WgLestaAPI\n```\n\n## Example of use\n\n### Async way\n\n`main.py` contains:\n```py\nfrom WgLestaAPI import aio\nimport asyncio\n\nmethod = aio.Method("account.info", "wot", account_id=563982544, application_id="your_app_id")\n\nresponse = asyncio.run(method.execute())\n\nprint(response)\n```\n\n`output` is:\n```json\n{"status": "ok", "meta": {"count": 1}, "data": {"563982544": {"client_language": "", "last_battle_time": 1569011404, "account_id": 563982544, "created_at": 1564320823, "updated_at": 1686648157, ... "tanking_factor": 0.0}, "frags": None}, "nickname": "tankalxat34", "logout_at": 1597741881}\n```\n\n### No-async way\n\n```py\nfrom WgLestaAPI import Application\n\n# Creating a Query with your application_id\nquery = Application.Query(application_id=APP_ID)\n\n# Adding the necessary parameters\nquery.extend(search="tank", limit=5)\n\n# Creating the method `account.list` of the game World of Tanks Blitz on the EU-region with the passed parameters\nm = Application.Method("account.list", game_shortname="wotb", query=query, region="eu")\n\n# Executing the method\nmExecuted = m.execute()\n\n# Your handing of server response\nprint(mExecuted["data"][0]["account_id"]) # 58114596\n\n# If you wish, you can follow a link to the official website of the API owner with documentation\nprint(m.docs) # https://developers.wargaming.net/reference/all/wotb/account/list/\n```\n\n## Library functionality\n\nThe library implements the basic functions of **API Lesta Games** and **API Wargaming.net**. All requests are made through your application, which you previously created on [<img src="docs/icons/lesta.ico" width=14px> Lesta Games](https://developers.lesta.ru/applications/) or on [<img src="docs/icons/wg.ico" width=14px> Wargaming.net](https://developers.wargaming.net/applications/). Some features are listed below:\n- Getting information about the player, his equipment and medals.\n- Obtaining information about the clan.\n- Getting information about vehicles.\n- *And other methods.*\n\n## Copyright Notice\n\n<div style="justify-content: center; text-align: center;">\n<a href="https://developers.lesta.ru/"><img src="https://developers.lesta.ru/static/1.13.1_lst/assets/img/header/lesta_dev_logo.png" width="178px" style="margin: 20px;"></a>\n<a href="https://developers.wargaming.net/"><img src="docs/icons/wg_logo.png" width="150px" style="margin: 20px;"></a>\n</div>\n\n- 2023 © Alexander Podstrechnyy. \n    - [tankalxat34@gmail.com](mailto:tankalxat34@gmail.com?subject=lestagamesapi)\n    - [VKontakte](https://vk.com/tankalxat34)\n    - [Telegram](https://tankalxat34.t.me)\n    - [GithHub](https://github.com/tankalxat34/wglestaapi)\n- 2023 © Wargaming.net. All rights reserved.\n    - [User Support Center](http://support.wargaming.net/)\n    - [Official website](https://wargaming.net/)\n    - [License Agreement](https://eu.wargaming.net/user_agreement/)\n    - [Privacy Policy](https://eu.wargaming.net/privacy_policy/)\n- 2023 © Lesta Games. All rights reserved. \n    - [User Support Center](https://lesta.ru/support/)\n    - [Official website](https://lesta.ru/)\n    - [License Agreement](https://developers.lesta.ru/documentation/rules/agreement/)\n    - [Privacy Policy](https://legal.lesta.ru/privacy-policy/)\n\n*This program code is not a product of Lesta Games and was developed according to Lesta Games DPP rules.*\n\n*This program code is not a product of Wargaming.net and is developed according to WG DPP rules.*\n',
    'author': 'Alexander Podstrechnyy',
    'author_email': 'tankalxat34@gmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/tankalxat34/WgLestaAPI',
    'packages': packages,
    'package_data': package_data,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
